package com.hrsk.cloud.eg.domain.api;

import com.google.common.base.Function;
import com.hrsk.cloud.eg.client.dto.cmd.RouteCmd;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.EgressApiErrorCodeEnum;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiRequest;
import com.hrsk.cloud.eg.domain.api.channel.guide.http.HttpApiResponse;
import com.hrsk.cloud.eg.domain.api.route.ApiRoute;
import com.hrsk.pangu.tool.exception.BizException;

import java.util.List;
import java.util.Map;

/**
 * @author: bianlanzhou
 * @create: 2024-11-10 16:18
 * @description: API实体
 **/
public class Api {
    /**
     * API通道列表
     */
    private List<ApiChannel> apiChannels;
    /**
     * 最终目标通道
     */
    private ApiChannel target;

    /**
     * 构造函数
     * @param apiChannels
     */
    public Api(List<ApiChannel> apiChannels) {
        this.apiChannels = apiChannels;
    }

    /**
     * 调用
     * @param input 入参
     */
    public String invoke(Map<String,Object> input, Function<HttpApiRequest, HttpApiResponse> httpClientFunc){
        if(target == null){
            throw new BizException(EgressApiErrorCodeEnum.AVAILABLE_API_CHANNEL_NOT_EXIST.getCode(),EgressApiErrorCodeEnum.API_CHANNEL_NOT_EXIST.getMessage());
        }
        return target.invoke(input,httpClientFunc);
    }

    /**
     * 路由
     * @param route 路由
     * @return 路由后的API
     */
    public Api route(RouteCmd route){
        target = ApiRoute.getInstance().route(apiChannels,route);
        return this;
    }
}
