package com.hrsk.cloud.eg.domain.api.channel.guide.resolver.vo;

import com.google.common.collect.Maps;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.ValueObject;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.ValueObjectTypeEnum;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.ApiContext;
import com.hrsk.pangu.tool.exception.BizException;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;

import java.util.Map;

/**
 * @author: bianlanzhou
 * @create: 2024-08-01 09:53
 * @description: 值对象处理器管理器
 **/
@Slf4j
public class ValueObjectResolverManager {
    /**
     * 解析器映射
     */
    private static final Map<String,ValueObjectResolver> RESOLVERS = Maps.newHashMap();
    /**
     * INSTANCE
     */
    private static final ValueObjectResolverManager INSTANCE = new ValueObjectResolverManager();

    /**
     * 构造函数
     */
    private ValueObjectResolverManager(){
        log.info("开始注册ValueObject解析器......");
        RESOLVERS.put(ValueObjectTypeEnum.SPEL.getType(),new SpelValueObjectResolver());
        RESOLVERS.put(ValueObjectTypeEnum.BASIC.getType(),new BasicTypeValueObjectResolver());
        RESOLVERS.put(ValueObjectTypeEnum.JSON_PATH.getType(),new JsonPathValueObjectResolver());
        log.info("结束注册ValueObject解析器，加载内容：{},{},{}.",ValueObjectTypeEnum.SPEL.getType(),ValueObjectTypeEnum.BASIC.getType(),ValueObjectTypeEnum.JSON_PATH.getType());
    }

    /**
     * 获取实例
     * @return 实例
     */
    public static ValueObjectResolverManager getInstance(){
        return INSTANCE;
    }

    /**
     * 解析
     * @param valueObject 值对象
     * @param context 上下文
     * @return 解析结果
     */
    public Object resolve(ValueObject valueObject, ApiContext context){
        String type = valueObject.getType();
        String key = valueObject.getType();
        if(StringUtils.equalsAnyIgnoreCase(type, BasicTypeValueObjectResolver.BASIC_TYPES)){
            key = ValueObjectTypeEnum.BASIC.getType();
        }
        if(StringUtils.isBlank(key)){
            throw new BizException("目前不支持此类型的解析!");
        }
        return RESOLVERS.get(key).resolve(valueObject,context);
    }

}
