package com.hrsk.cloud.eg.domain.api.route;

import com.google.common.collect.Lists;
import com.hrsk.cloud.eg.client.dto.cmd.RouteCmd;
import com.hrsk.cloud.eg.domain.api.ApiChannel;
import com.hrsk.cloud.eg.domain.api.route.strategy.ChannelCodeBasedRouteStrategy;
import com.hrsk.cloud.eg.domain.api.route.strategy.RouteStrategy;

import java.util.List;

/**
 * @author: bianlanzhou
 * @create: 2024-11-10 16:21
 * @description:API路由
 **/
public class ApiRoute {
    /**
     * 单例
     */
    private static final ApiRoute ROUTE = new ApiRoute();
    /**
     * 路由策略列表
     */
    private List<RouteStrategy> routeStrategies = Lists.newArrayList();

    /**
     * 获取实例
     * @return 实例
     */
    public static final ApiRoute getInstance(){
        return ROUTE;
    }
    /**
     * 构造函数
     */
    private ApiRoute(){
        routeStrategies.add(new ChannelCodeBasedRouteStrategy());
    }

    /**
     * 路由
     * @param apiChannels API通道列表
     */
    public ApiChannel route(List<ApiChannel> apiChannels, RouteCmd route){
        for(RouteStrategy routeStrategy : routeStrategies){
            if(routeStrategy.route(apiChannels,route)){
                break;
            }
        }
        if(apiChannels.size()>0){
            return apiChannels.get(0);
        }
        return null;
    }

}
