package com.hrsk.cloud.eg.domain.api.channel.guide.resolver.payload;

import com.google.common.collect.Maps;
import com.google.gson.JsonObject;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.ApiContext;
import com.hrsk.cloud.eg.domain.api.channel.guide.common.ContentTypeEnum;
import lombok.extern.slf4j.Slf4j;

import java.util.Map;

/**
 * @author: bianlanzhou
 * @create: 2024-08-01 17:38
 * @description: api payload 管理器
 **/
@Slf4j
public class ApiPayloadResolverManage {
    /**
     * PAYLOAD MAP
     */
    private static final Map<String, ApiPayloadResolver> RESOLVER_MAP = Maps.newHashMap();
    /**
     * INSTANCE
     */
    private static final ApiPayloadResolverManage INSTANCE = new ApiPayloadResolverManage();

    static {
        regist();
    }

    private ApiPayloadResolverManage(){}

    /**
     * 获取实例
     * @return 实例
     */
    public static ApiPayloadResolverManage getInstance(){
        return INSTANCE;
    }

    /**
     * 解析
     * @param code 编码
     * @param apiContext 上下文
     * @return 解析结果
     */
    public JsonObject resolve(String code, String template, ApiContext apiContext){
        return RESOLVER_MAP.get(code).resolve(template,apiContext);
    }

    /**
     * 注册
     */
    private static void regist(){
        log.info("开始注册Payload解析器!");
        RESOLVER_MAP.put(ContentTypeEnum.APPLICATION_JSON.getCode(),new ApiJsonPayloadResolver());
        RESOLVER_MAP.put(ContentTypeEnum.JSON.getCode(),new ApiJsonPayloadResolver());
    }
}
